# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/features/feature_set.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.feature_store.features import feature_set_types_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__types__pb2
from _qwak_proto.qwak.feature_store.entities import entity_pb2 as qwak_dot_feature__store_dot_entities_dot_entity__pb2
from _qwak_proto.qwak.feature_store.features import feature_set_state_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__state__pb2
from _qwak_proto.qwak.feature_store.features import feature_set_attribute_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__attribute__pb2
from _qwak_proto.qwak.feature_store.v1.common.source_code import source_code_pb2 as qwak_dot_feature__store_dot_v1_dot_common_dot_source__code_dot_source__code__pb2
from _qwak_proto.qwak.feature_store.repository.common import platform_pb2 as qwak_dot_feature__store_dot_repository_dot_common_dot_platform__pb2
from _qwak_proto.qwak.feature_store.platform import platform_details_pb2 as qwak_dot_feature__store_dot_platform_dot_platform__details__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-qwak/feature_store/features/feature_set.proto\x12\x1bqwak.feature.store.features\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x33qwak/feature_store/features/feature_set_types.proto\x1a(qwak/feature_store/entities/entity.proto\x1a\x33qwak/feature_store/features/feature_set_state.proto\x1a\x37qwak/feature_store/features/feature_set_attribute.proto\x1a:qwak/feature_store/v1/common/source_code/source_code.proto\x1a\x33qwak/feature_store/repository/common/platform.proto\x1a\x32qwak/feature_store/platform/platform_details.proto\"\xfc\x01\n\nFeatureSet\x12Q\n\x16\x66\x65\x61ture_set_definition\x18\x01 \x01(\x0b\x32\x31.qwak.feature.store.features.FeatureSetDefinition\x12\x41\n\x08metadata\x18\x02 \x01(\x0b\x32/.qwak.feature.store.features.FeatureSetMetadata\x12X\n\x1b\x64\x65ployed_models_in_use_link\x18\x03 \x03(\x0b\x32\x33.qwak.feature.store.features.DeployedModelInUseLink\"\xa5\x01\n\x0e\x46\x65\x61turesetInfo\x12P\n\x15\x66\x65\x61tureset_definition\x18\x01 \x01(\x0b\x32\x31.qwak.feature.store.features.FeatureSetDefinition\x12\x41\n\x08metadata\x18\x02 \x01(\x0b\x32/.qwak.feature.store.features.FeatureSetMetadata\"x\n\x11\x46\x65\x61turesetSummary\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12I\n\x10\x66\x65\x61ture_set_type\x18\x03 \x01(\x0e\x32/.qwak.feature.store.features.FeatureSetTypeView\"\xf6\x04\n\x14\x46\x65\x61tureSetDefinition\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x45\n\x10\x66\x65\x61ture_set_spec\x18\x02 \x01(\x0b\x32+.qwak.feature.store.features.FeatureSetSpec\x12:\n\x06status\x18\x03 \x01(\x0e\x32*.qwak.feature.store.features.FeatureStatus\x12g\n feature_set_last_execution_state\x18\x04 \x01(\x0e\x32\x39.qwak.feature.store.features.FeatureSetLastExecutionStateB\x02\x18\x01\x12U\n\x0e\x66\x65\x61ture_health\x18\x05 \x01(\x0e\x32\x39.qwak.feature.store.features.FeatureSetLastExecutionStateB\x02\x18\x01\x12K\n\x11\x66\x65\x61ture_set_state\x18\x06 \x03(\x0b\x32,.qwak.feature.store.features.FeatureSetStateB\x02\x18\x01\x12*\n\x1eqwak_internal_protocol_version\x18\x07 \x01(\x05\x42\x02\x18\x01\x12!\n\x19\x66\x65\x61tureset_version_number\x18\x08 \x01(\x05\x12H\n\x10platform_details\x18\t \x01(\x0b\x32,.qwak.feature.store.platform.PlatformDetailsH\x00\x42\x1d\n\x1b\x66\x65\x61tureset_platform_details\"\xdb\x04\n\x0e\x46\x65\x61tureSetSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x45\n\x08metadata\x18\x02 \x01(\x0b\x32\x33.qwak.feature.store.features.FeatureSetUserMetadata\x12\x16\n\ngit_commit\x18\x03 \x01(\tB\x02\x18\x01\x12=\n\x06\x65ntity\x18\x04 \x01(\x0b\x32-.qwak.feature.store.entities.EntityDefinition\x12\x45\n\x10\x66\x65\x61ture_set_type\x18\x05 \x01(\x0b\x32+.qwak.feature.store.features.FeatureSetType\x12\x36\n\x08\x66\x65\x61tures\x18\x06 \x03(\x0b\x32$.qwak.feature.store.features.Feature\x12*\n\x1eqwak_internal_protocol_version\x18\x07 \x01(\x05\x42\x02\x18\x01\x12V\n\x10source_code_spec\x18\x08 \x01(\x0b\x32\x38.qwak.feature.store.v1.common.source_code.SourceCodeSpecB\x02\x18\x01\x12P\n\x15\x66\x65\x61tureset_attributes\x18\t \x01(\x0b\x32\x31.qwak.feature.store.features.FeaturesetAttributes\x12$\n\x1a\x66\x65\x61tureset_repository_name\x18\n \x01(\tH\x00\x42\"\n featureset_repository_identifier\"\xb8\x01\n\x16\x46\x65\x61tureSetUserMetadata\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x64\n featureset_version_user_metadata\x18\x04 \x01(\x0b\x32:.qwak.feature.store.features.FeaturesetVersionUserMetadata\"0\n\x1d\x46\x65\x61turesetVersionUserMetadata\x12\x0f\n\x07\x63omment\x18\x01 \x01(\t\"\x9d\x02\n\x12\x46\x65\x61tureSetMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x34\n\x10last_modified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x04 \x01(\t\x12[\n\x1b\x66\x65\x61tureset_version_metadata\x18\x05 \x01(\x0b\x32\x36.qwak.feature.store.features.FeaturesetVersionMetadata\x12\x16\n\x0e\x65nvironment_id\x18\x06 \x01(\t\"_\n\x19\x46\x65\x61turesetVersionMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\">\n\x16\x44\x65ployedModelInUseLink\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x12\n\nmodel_name\x18\x02 \x01(\t\"5\n\x07\x46\x65\x61ture\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x01 \x01(\t\x12\x14\n\x0c\x66\x65\x61ture_type\x18\x02 \x01(\t\"\xa7\x01\n\x16\x44\x65ployedFeatureSetSpec\x12\x45\n\x10\x66\x65\x61ture_set_spec\x18\x01 \x01(\x0b\x32+.qwak.feature.store.features.FeatureSetSpec\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x02 \x01(\t\x12\x12\n\naccount_id\x18\x03 \x01(\t\x12\x1a\n\x12\x66\x65\x61tureset_version\x18\x04 \x01(\x05\"O\n\x0e\x46\x65\x61tureSetList\x12=\n\x0c\x66\x65\x61ture_sets\x18\x01 \x03(\x0b\x32\'.qwak.feature.store.features.FeatureSet*\xb4\x01\n\rFeatureStatus\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05VALID\x10\x01\x12\x0b\n\x07\x44\x45LETED\x10\x02\x12\x17\n\x13REGISTRATION_FAILED\x10\x03\x12\x1c\n\x18REGISTRATION_IN_PROGRESS\x10\x04\x12\x18\n\x14\x44\x45LETION_IN_PROGRESS\x10\x05\x12\x13\n\x0f\x44\x45LETION_FAILED\x10\x06\x12\x18\n\x14\x42\x41\x43KFILL_IN_PROGRESS\x10\x07*\x92\x01\n\x19\x46\x65\x61turesetSchedulingState\x12\x1c\n\x18SCHEDULING_STATE_INVALID\x10\x00\x12\x1c\n\x18SCHEDULING_STATE_ENABLED\x10\x01\x12\x1b\n\x17SCHEDULING_STATE_PAUSED\x10\x02\x12\x1c\n\x18SCHEDULING_STATE_UNKNOWN\x10\x03\x42[\n&com.qwak.ai.feature.store.features.apiP\x01Z/qwak/featurestore/features;featurestorefeaturesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.features.feature_set_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.feature.store.features.apiP\001Z/qwak/featurestore/features;featurestorefeatures'
  _FEATURESETDEFINITION.fields_by_name['feature_set_last_execution_state']._options = None
  _FEATURESETDEFINITION.fields_by_name['feature_set_last_execution_state']._serialized_options = b'\030\001'
  _FEATURESETDEFINITION.fields_by_name['feature_health']._options = None
  _FEATURESETDEFINITION.fields_by_name['feature_health']._serialized_options = b'\030\001'
  _FEATURESETDEFINITION.fields_by_name['feature_set_state']._options = None
  _FEATURESETDEFINITION.fields_by_name['feature_set_state']._serialized_options = b'\030\001'
  _FEATURESETDEFINITION.fields_by_name['qwak_internal_protocol_version']._options = None
  _FEATURESETDEFINITION.fields_by_name['qwak_internal_protocol_version']._serialized_options = b'\030\001'
  _FEATURESETSPEC.fields_by_name['git_commit']._options = None
  _FEATURESETSPEC.fields_by_name['git_commit']._serialized_options = b'\030\001'
  _FEATURESETSPEC.fields_by_name['qwak_internal_protocol_version']._options = None
  _FEATURESETSPEC.fields_by_name['qwak_internal_protocol_version']._serialized_options = b'\030\001'
  _FEATURESETSPEC.fields_by_name['source_code_spec']._options = None
  _FEATURESETSPEC.fields_by_name['source_code_spec']._serialized_options = b'\030\001'
  _globals['_FEATURESTATUS']._serialized_start=3258
  _globals['_FEATURESTATUS']._serialized_end=3438
  _globals['_FEATURESETSCHEDULINGSTATE']._serialized_start=3441
  _globals['_FEATURESETSCHEDULINGSTATE']._serialized_end=3587
  _globals['_FEATURESET']._serialized_start=482
  _globals['_FEATURESET']._serialized_end=734
  _globals['_FEATURESETINFO']._serialized_start=737
  _globals['_FEATURESETINFO']._serialized_end=902
  _globals['_FEATURESETSUMMARY']._serialized_start=904
  _globals['_FEATURESETSUMMARY']._serialized_end=1024
  _globals['_FEATURESETDEFINITION']._serialized_start=1027
  _globals['_FEATURESETDEFINITION']._serialized_end=1657
  _globals['_FEATURESETSPEC']._serialized_start=1660
  _globals['_FEATURESETSPEC']._serialized_end=2263
  _globals['_FEATURESETUSERMETADATA']._serialized_start=2266
  _globals['_FEATURESETUSERMETADATA']._serialized_end=2450
  _globals['_FEATURESETVERSIONUSERMETADATA']._serialized_start=2452
  _globals['_FEATURESETVERSIONUSERMETADATA']._serialized_end=2500
  _globals['_FEATURESETMETADATA']._serialized_start=2503
  _globals['_FEATURESETMETADATA']._serialized_end=2788
  _globals['_FEATURESETVERSIONMETADATA']._serialized_start=2790
  _globals['_FEATURESETVERSIONMETADATA']._serialized_end=2885
  _globals['_DEPLOYEDMODELINUSELINK']._serialized_start=2887
  _globals['_DEPLOYEDMODELINUSELINK']._serialized_end=2949
  _globals['_FEATURE']._serialized_start=2951
  _globals['_FEATURE']._serialized_end=3004
  _globals['_DEPLOYEDFEATURESETSPEC']._serialized_start=3007
  _globals['_DEPLOYEDFEATURESETSPEC']._serialized_end=3174
  _globals['_FEATURESETLIST']._serialized_start=3176
  _globals['_FEATURESETLIST']._serialized_end=3255
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod
from dataclasses import dataclass, field
from datetime import datetime
from typing import Dict

from _qwak_proto.qwak.automation.v1.automation_pb2 import (
    Automation as AutomationProto,
    AutomationAudit as AutomationAuditProto,
    AutomationSpec as AutomationSpecProto,
)
from _qwak_proto.qwak.automation.v1.common_pb2 import (
    Metric as MetricProto,
    SqlMetric as SqlMetricProto,
)
from _qwak_proto.qwak.automation.v1.notification_pb2 import (
    CustomWebhook as CustomWebhookProto,
    HttpMethodType as HttpMethodTypeProto,
    Notification as NotificationProto,
    PostSlackNotification as PostSlackNotificationProto,
)
from _qwak_proto.qwak.automation.v1.trigger_pb2 import (
    MetricBasedTrigger as MetricBasedTriggerProto,
    NoneTrigger as NoneTriggerProto,
    OnBoardingTrigger as OnBoardingTriggerProto,
    ScheduledTrigger as ScheduledTriggerProto,
    Trigger as TriggerProto,
)
from google.protobuf.timestamp_pb2 import Timestamp
from qwak.automations.batch_execution_action import BatchExecution
from qwak.automations.build_and_deploy_action import QwakBuildDeploy
from qwak.automations.common import (
    Action,
    ThresholdDirection,
    map_proto_threshold_to_direction,
    map_threshold_direction_to_proto,
)


@dataclass
class Trigger(ABC):
    def to_proto(self):
        # abstract method
        pass

    @staticmethod
    @abstractmethod
    def from_proto(message: TriggerProto):
        # abstract method
        pass


@dataclass
class Metric(ABC):
    @abstractmethod
    def to_proto(self):
        # abstract method
        pass

    @staticmethod
    @abstractmethod
    def from_proto(message: MetricProto):
        # abstract method
        pass


@dataclass
class ScheduledTrigger(Trigger):
    cron: str = field(default="")
    interval: str = field(default="")

    def to_proto(self):
        return (
            TriggerProto(
                scheduled_trigger=ScheduledTriggerProto(interval=self.interval)
            )
            if self.interval
            else TriggerProto(scheduled_trigger=ScheduledTriggerProto(cron=self.cron))
        )

    @staticmethod
    def from_proto(message: TriggerProto):
        return ScheduledTrigger(
            cron=message.scheduled_trigger.cron,
            interval=message.scheduled_trigger.interval,
        )


@dataclass
class MetricBasedTrigger(Trigger):
    name: str = field(default="")
    metric: Metric = field(default="")
    direction: ThresholdDirection = field(default=ThresholdDirection.ABOVE)
    threshold: str = field(default="")
    override_cron: str = field(default="")

    def to_proto(self):
        return TriggerProto(
            metric_based_trigger=MetricBasedTriggerProto(
                name=self.name,
                threshold=self.threshold,
                metric=self.metric.to_proto(),
                threshold_direction=map_threshold_direction_to_proto(self.direction),
                override_cron=self.override_cron,
            )
        )

    @staticmethod
    def from_proto(message: TriggerProto):
        metric = map_metric_name_to_class(
            message.metric_based_trigger.metric.WhichOneof("metric")
        )
        return MetricBasedTrigger(
            name=message.metric_based_trigger.name,
            metric=(
                metric.from_proto(message.metric_based_trigger.metric)
                if metric
                else None
            ),
            threshold=message.metric_based_trigger.threshold,
            direction=map_proto_threshold_to_direction(
                message.metric_based_trigger.threshold_direction
            ),
            override_cron=message.metric_based_trigger.override_cron,
        )


@dataclass
class NoneTrigger(Trigger):
    def to_proto(self):
        return TriggerProto(none_trigger=NoneTriggerProto())

    @staticmethod
    def from_proto(message: TriggerProto):
        return NoneTrigger()


@dataclass
class OnBoardingTrigger(Trigger):
    def to_proto(self):
        return TriggerProto(on_boarding_trigger=OnBoardingTriggerProto())

    @staticmethod
    def from_proto(message: TriggerProto):
        return OnBoardingTrigger()


@dataclass
class SqlMetric(Metric):
    sql_query: str = field(default="")

    def to_proto(self):
        return MetricProto(sql_metric=SqlMetricProto(sql_query=self.sql_query))

    @staticmethod
    def from_proto(message: MetricProto):
        return SqlMetric(sql_query=message.sql_metric.sql_query)


@dataclass
class Notification(ABC):
    def to_proto(self):
        # abstract method
        pass

    @staticmethod
    @abstractmethod
    def from_proto(message: TriggerProto):
        # abstract method
        pass


@dataclass
class SlackNotification(Notification):
    webhook: str = field(default="")

    def to_proto(self):
        return NotificationProto(
            post_slack_notification=PostSlackNotificationProto(
                webhook=self.webhook,
            )
        )

    @staticmethod
    def from_proto(message: NotificationProto):
        return SlackNotification(
            webhook=message.post_slack_notification.webhook,
        )

    def __str__(self):
        return f"Slack Notification:\n webhook:{self.webhook}\n"


@dataclass
class CustomWebhook(Notification):
    url: str = field(default="")
    http_method: str = field(default="GET")
    headers: Dict[str, str] = field(default_factory=dict)
    data: Dict[str, str] = field(default_factory=dict)

    _HTTP_NAME_TO_STATUS_MAPPING = {
        "GET": HttpMethodTypeProto.HTTP_METHOD_TYPE_GET,
        "POST": HttpMethodTypeProto.HTTP_METHOD_TYPE_POST,
        "PUT": HttpMethodTypeProto.HTTP_METHOD_TYPE_PUT,
        "PATCH": HttpMethodTypeProto.HTTP_METHOD_TYPE_PATCH,
        "DELETE": HttpMethodTypeProto.HTTP_METHOD_TYPE_DELETE,
        "HEAD": HttpMethodTypeProto.HTTP_METHOD_TYPE_HEAD,
    }

    _HTTP_STATUS_TO_NAME_MAPPING = {
        v: k for k, v in _HTTP_NAME_TO_STATUS_MAPPING.items()
    }

    def __post_init__(self):
        if self.http_method.upper() not in self._HTTP_NAME_TO_STATUS_MAPPING.keys():
            raise ValueError(
                f"HTTP method {self.http_method} is not a valid method. Available options are "
                f"{list(self._HTTP_NAME_TO_STATUS_MAPPING.keys())}"
            )

    def to_proto(self):
        return NotificationProto(
            custom_webhook=CustomWebhookProto(
                url=self.url,
                http_method=self._HTTP_NAME_TO_STATUS_MAPPING.get(
                    self.http_method.upper()
                ),
                headers=self.headers,
                data=self.data,
            )
        )

    @staticmethod
    def from_proto(message: NotificationProto):
        return CustomWebhook(
            url=message.custom_webhook.url,
            data=message.custom_webhook.data,
            headers=message.custom_webhook.headers,
            http_method=CustomWebhook._HTTP_STATUS_TO_NAME_MAPPING.get(
                message.custom_webhook.http_method
            ),
        )

    def __str__(self):
        return f"Custom webhook:\n url:{self.url}\n data:{self.data}\n headers:{self.headers}\n http method:{self.http_method}\n"


@dataclass
class AutomationAudit(ABC):
    date: datetime = field(default=datetime.now())
    user_id: str = field(default="")

    def to_proto(self):
        timestamp = Timestamp()
        timestamp.FromDatetime(self.date)
        return AutomationAuditProto(user_id=self.user_id, date=timestamp)

    @staticmethod
    def from_proto(message: AutomationAuditProto):
        return AutomationAudit(
            user_id=message.user_id,
            date=datetime.fromtimestamp(
                message.date.seconds + message.date.nanos / 1e9
            ),
        )


@dataclass
class Automation:
    id: str = field(default="")
    name: str = field(default="")
    model_id: str = field(default="")
    execute_immediately: bool = field(default=False)
    trigger: Trigger = field(default_factory=Trigger)
    action: Action = field(default_factory=Action)
    description: str = field(default="")
    environment: str = field(default="")
    is_enabled: bool = field(default=True)
    is_deleted: bool = field(default=False)
    is_sdk_v1: bool = field(default=False)
    create_audit: AutomationAudit = field(default_factory=AutomationAudit)
    on_error: Notification = field(default=None)
    on_success: Notification = field(default=None)
    jfrog_token_id: str = field(default="")
    platform_url: str = field(default="")

    def to_proto(self):
        return AutomationProto(
            automation_id=self.id,
            automation_spec=AutomationSpecProto(
                automation_name=self.name,
                is_enabled=self.is_enabled,
                is_sdk_v1=self.is_sdk_v1,
                execute_immediately=self.execute_immediately,
                model_id=self.model_id,
                action=self.action.to_proto(),
                trigger=self.trigger.to_proto() if self.trigger is not None else None,
                on_error=(
                    self.on_error.to_proto() if self.on_error is not None else None
                ),
                on_success=(
                    self.on_success.to_proto() if self.on_success is not None else None
                ),
            ),
            qwak_environment_id=self.environment,
            create_audit=self.create_audit.to_proto(),
            is_deleted=self.is_deleted,
            jfrog_token_id=self.jfrog_token_id,
            platform_url=self.platform_url,
        )

    @staticmethod
    def from_proto(message: AutomationProto):
        action = map_action_name_to_class(
            message.automation_spec.action.WhichOneof("action")
        )
        trigger = map_trigger_name_to_class(
            message.automation_spec.trigger.WhichOneof("trigger")
        )
        on_error_notification = map_notification_name_to_class(
            message.automation_spec.on_error.WhichOneof("notification")
        )
        on_success_notification = map_notification_name_to_class(
            message.automation_spec.on_success.WhichOneof("notification")
        )

        return Automation(
            id=message.automation_id,
            name=message.automation_spec.automation_name,
            description=message.automation_spec.automation_description,
            execute_immediately=message.automation_spec.execute_immediately,
            model_id=message.automation_spec.model_id,
            is_enabled=message.automation_spec.is_enabled,
            is_sdk_v1=message.automation_spec.is_sdk_v1,
            is_deleted=message.is_deleted,
            action=(
                action.from_proto(message.automation_spec.action) if action else None
            ),
            trigger=(
                trigger.from_proto(message.automation_spec.trigger) if trigger else None
            ),
            environment=message.qwak_environment_id,
            create_audit=AutomationAudit.from_proto(message.create_audit),
            on_error=(
                on_error_notification.from_proto(message.automation_spec.on_error)
                if on_error_notification
                else None
            ),
            on_success=(
                on_success_notification.from_proto(message.automation_spec.on_success)
                if on_success_notification
                else None
            ),
            jfrog_token_id=message.jfrog_token_id,
            platform_url=message.platform_url,
        )

    def __str__(self):
        on_error = f"\nOn Error: {self.on_error}" if self.on_error else ""
        on_success = f"\nOn Success: {self.on_success}" if self.on_success else ""
        return f"Id: {self.id}\tName: {self.name}\tModel: {self.model_id}\nDescription: {self.description}\nAction: {self.action}\nTrigger: {self.trigger}{on_error}{on_success}"


def map_notification_name_to_class(notification_name: str):
    mapping = {
        "post_slack_notification": SlackNotification,
        "custom_webhook": CustomWebhook,
    }
    return mapping.get(notification_name)


def map_action_name_to_class(action_name: str):
    mapping = {"build_deploy": QwakBuildDeploy, "batch_execution": BatchExecution}
    return mapping.get(action_name)


def map_trigger_name_to_class(trigger_name: str):
    mapping = {
        "scheduled_trigger": ScheduledTrigger,
        "metric_based_trigger": MetricBasedTrigger,
        "none_trigger": NoneTrigger,
        "on_boarding_trigger": OnBoardingTrigger,
    }

    return mapping.get(trigger_name)


def map_metric_name_to_class(metric_name: str):
    mapping = {"sql_metric": SqlMetric}
    return mapping.get(metric_name)



from abc import ABCMeta
from dataclasses import field, dataclass
from pathlib import Path
from typing import Optional

from qwak.clients.administration.eco_system.client import EcosystemClient
from qwak.clients.build_orchestrator import BuildOrchestratorClient
from qwak.clients.instance_template.client import InstanceTemplateManagementClient
from qwak.clients.model_management import ModelsManagementClient
from qwak.inner.build_logic.dependency_manager_type import DependencyManagerType
from qwak.inner.di_configuration.account import UserAccount, UserAccountConfiguration


@dataclass
class Context(metaclass=ABCMeta):
    # Clients
    client_builds_orchestrator: BuildOrchestratorClient = field(
        default_factory=BuildOrchestratorClient
    )
    client_models_management: ModelsManagementClient = field(
        default_factory=ModelsManagementClient
    )
    client_instance_template: InstanceTemplateManagementClient = field(
        default_factory=InstanceTemplateManagementClient
    )
    client_ecosystem: EcosystemClient = field(default_factory=EcosystemClient)

    # General
    user_account: UserAccount = field(
        default_factory=UserAccountConfiguration().get_user_config
    )

    # Pre fetch validation
    build_id: str = field(default="")
    model_id: str = field(default="")
    build_name: str = field(default="")
    project_uuid: str = field(default="")
    host_temp_local_build_dir: Path = field(default=None)
    model_uri: Path = field(default=None)
    git_credentials: str = field(default="")
    git_ssh_key: str = field(default="")

    # Fetch model
    git_commit_id: Optional[str] = field(default=None)

    # Post fetch validation
    dependency_manager_type: DependencyManagerType = field(
        default=DependencyManagerType.UNKNOWN
    )
    model_relative_dependency_file: Path = field(default=None)
    model_relative_dependency_lock_file: Path = field(default=None)

    # Upload model
    model_code_remote_url: Optional[str] = field(default=None)
    qwak_sdk_version: Optional[str] = field(default=None)

    # Image
    base_image: Optional[str] = field(default=None)

    # Upload Custom Wheels
    custom_runtime_wheel: Optional[Path] = field(default=None)
    custom_core_wheel: Optional[Path] = field(default=None)

    platform_url: Optional[str] = field(
        default_factory=UserAccountConfiguration().retrieve_platform_url
    )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _BuildArtifactType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BuildArtifactTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BuildArtifactType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_ARTIFACT_TYPE: _BuildArtifactType.ValueType  # 0
    DATA_ARTIFACT_TYPE: _BuildArtifactType.ValueType  # 1
    FILE_ARTIFACT_TYPE: _BuildArtifactType.ValueType  # 2
    CODE_ARTIFACT_TYPE: _BuildArtifactType.ValueType  # 3

class BuildArtifactType(_BuildArtifactType, metaclass=_BuildArtifactTypeEnumTypeWrapper):
    """build artifact Types"""

INVALID_ARTIFACT_TYPE: BuildArtifactType.ValueType  # 0
DATA_ARTIFACT_TYPE: BuildArtifactType.ValueType  # 1
FILE_ARTIFACT_TYPE: BuildArtifactType.ValueType  # 2
CODE_ARTIFACT_TYPE: BuildArtifactType.ValueType  # 3
global___BuildArtifactType = BuildArtifactType

class BuildUploadUrlParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    TAG_VALUE_FIELD_NUMBER: builtins.int
    ARTIFACT_TYPE_FIELD_NUMBER: builtins.int
    USE_CLOUD_PROVIDER_STORAGE_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """Model ID"""
    build_id: builtins.str
    """Build Id"""
    tag_value: builtins.str
    """Tag to save the artifact by"""
    artifact_type: global___BuildArtifactType.ValueType
    """The type of the artifact to upload"""
    use_cloud_provider_storage: builtins.bool
    """When true, will use the cloud provider URL"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        build_id: builtins.str = ...,
        tag_value: builtins.str = ...,
        artifact_type: global___BuildArtifactType.ValueType = ...,
        use_cloud_provider_storage: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_provider_option", b"cloud_provider_option", "use_cloud_provider_storage", b"use_cloud_provider_storage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifact_type", b"artifact_type", "build_id", b"build_id", "cloud_provider_option", b"cloud_provider_option", "model_id", b"model_id", "tag_value", b"tag_value", "use_cloud_provider_storage", b"use_cloud_provider_storage"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["cloud_provider_option", b"cloud_provider_option"]) -> typing_extensions.Literal["use_cloud_provider_storage"] | None: ...

global___BuildUploadUrlParameters = BuildUploadUrlParameters



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/artifactory_settings/artifactory_settings.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4qwak/artifactory_settings/artifactory_settings.proto\x12\x1d\x63om.qwak.artifactory_settings\"\xbb\x01\n\x13\x41rtifactorySettings\x12!\n\x19\x63ontainer_registry_prefix\x18\x01 \x01(\t\x12 \n\x18internal_repository_name\x18\x02 \x01(\t\x12_\n\x16\x61uthentication_details\x18\x03 \x01(\x0b\x32?.com.qwak.artifactory_settings.ArtifactoryAuthenticationDetails\"V\n ArtifactoryAuthenticationDetails\x12\r\n\x05token\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x11\n\ttenant_id\x18\x03 \x01(\tB;\n\x1d\x63om.qwak.artifactory_settingsB\x18\x41rtifactorySettingsProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.artifactory_settings.artifactory_settings_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.artifactory_settingsB\030ArtifactorySettingsProtoP\001'
  _globals['_ARTIFACTORYSETTINGS']._serialized_start=88
  _globals['_ARTIFACTORYSETTINGS']._serialized_end=275
  _globals['_ARTIFACTORYAUTHENTICATIONDETAILS']._serialized_start=277
  _globals['_ARTIFACTORYAUTHENTICATIONDETAILS']._serialized_end=363
# @@protoc_insertion_point(module_scope)



import importlib.metadata
import platform
from typing import List


def get_environment_dependencies() -> List[str]:
    distributions = importlib.metadata.distributions()
    return sorted(
        [f"{dist.metadata['Name']}=={dist.version}" for dist in distributions]
    )


def get_environment_details() -> List[str]:
    return [
        f"arch={platform.architecture()[0]}",
        f"cpu={platform.processor()}",
        f"platform={platform.platform()}",
        f"python_version={platform.python_version()}",
        f"python_implementation={platform.python_implementation()}",
        f"python_compiler={platform.python_compiler()}",
    ]



import fnmatch
import os
import re
import shutil
from pathlib import Path
from typing import Iterable, List, Optional

from qwak.exceptions import QwakGeneralBuildException
from qwak.inner.build_logic.constants.temp_dir import TEMP_LOCAL_MODEL_DIR
from qwak.inner.build_logic.interface.build_logger_interface import BuildLogger
from qwak.inner.build_logic.interface.step_inteface import Step
from qwak.inner.build_logic.tools.dependencies_tools import DEPS_MANAGER_FILE_MAP

# Hidden directories setting
HIDDEN_FILES_PREFIX = "."
HIDDEN_DIRS_TO_INCLUDE = [".dvc"]
IGNORED_PATTERNS_FOR_UPLOAD = [r"\..*", r"__pycache__"]
QWAK_IGNORE_FILE_NAME = ".qwakignore"


def copytree(
    src,
    dst,
    symlinks=False,
    ignore=None,
    ignore_dangling_symlinks=False,
    dirs_exist_ok=False,
):
    names = os.listdir(src)
    if ignore is not None:
        ignored_names = ignore(src, names)
    else:
        ignored_names = set()

    os.makedirs(dst, exist_ok=dirs_exist_ok)
    errors = []
    for name in names:
        if name in ignored_names:
            continue
        srcname = os.path.join(src, name)
        dstname = os.path.join(dst, name)
        try:
            if os.path.islink(srcname):
                linkto = os.readlink(srcname)
                if symlinks:
                    # We can't just leave it to `copy_function` because legacy
                    # code with a custom `copy_function` may rely on copytree
                    # doing the right thing.
                    os.symlink(linkto, dstname)
                    shutil.copystat(srcname, dstname, follow_symlinks=not symlinks)
                else:
                    # ignore dangling symlink if the flag is on
                    if not os.path.exists(linkto) and ignore_dangling_symlinks:
                        continue
                    # otherwise let the copy occurs. copy2 will raise an error
                    if os.path.isdir(srcname):
                        copytree(srcname, dstname, symlinks, ignore)
                    else:
                        shutil.copy2(srcname, dstname)
            elif os.path.isdir(srcname):
                copytree(srcname, dstname, symlinks, ignore)
            else:
                # Will raise a SpecialFileError for unsupported file types
                shutil.copy2(srcname, dstname)
        # catch the Error from the recursive copytree so that we can
        # continue with other files
        except shutil.Error as err:
            errors.extend(err.args[0])
        except OSError as why:
            errors.append((srcname, dstname, str(why)))
    try:
        shutil.copystat(src, dst)
    except OSError as why:
        # Copying file access times may fail on Windows
        if getattr(why, "winerror", None) is None:
            errors.append((src, dst, str(why)))
    if errors:
        raise shutil.Error(errors)
    return dst


def get_possible_dependency_lock_paths(dependency_path: Path):
    paths = []
    for _, dependency_file_object in DEPS_MANAGER_FILE_MAP.items():
        if dependency_file_object.lock_file_name:
            lock_file_path = (
                dependency_path.parent / dependency_file_object.lock_file_name
            )
            paths.append(lock_file_path)
    return paths


def get_files_to_ignore(directory: Path, patterns: Iterable[str] = ()):
    def ignore_hidden(file: Path, exclusions: List[str]):
        name = os.path.basename(os.path.abspath(file))
        is_hidden = name.startswith(HIDDEN_FILES_PREFIX) and (
            name != QWAK_IGNORE_FILE_NAME and name not in exclusions
        )
        return is_hidden

    def is_ignore_by_pattern(file: Path):
        return (
            len(
                [
                    pattern
                    for pattern in patterns
                    if re.search(fnmatch.translate(pattern), str(file))
                ]
            )
            != 0
        )

    return [
        file.name
        for file in Path(directory).rglob("*")
        if is_ignore_by_pattern(file)
        or ignore_hidden(file, exclusions=HIDDEN_DIRS_TO_INCLUDE)
    ]


def _replace_large_files_with_too_large_file_message(
    filtered_model: Path, max_bytes: Optional[int]
):
    def does_exceed_size(file: Path):
        file_size = file.lstat().st_size
        return file_size > max_bytes, file.lstat().st_size

    if max_bytes is None:
        return

    for root, dirs, files in os.walk(filtered_model):
        for file in files:
            file_path = Path(os.path.join(root, file))
            replace_content, file_size = does_exceed_size(file_path)
            if replace_content:
                Path(file_path).write_text(
                    f"File is too big to display. Size: {file_size} bytes"
                )


def zip_model(
    build_dir: Path,
    dependency_file: Path,
    dirs_to_include: List[str],
    zip_name: str,
    ignored_patterns: Iterable[str],
    max_bytes: Optional[int] = None,
    deps_lock_file: Optional[Path] = None,
):
    try:
        filtered_model = build_dir / zip_name
        ignored_patterns = get_files_to_ignore(
            directory=build_dir / TEMP_LOCAL_MODEL_DIR, patterns=ignored_patterns
        )

        for included_dir in dirs_to_include:
            dir_to_copy = build_dir / TEMP_LOCAL_MODEL_DIR / included_dir
            if dir_to_copy.is_dir():
                copytree(
                    src=build_dir / TEMP_LOCAL_MODEL_DIR / included_dir,
                    dst=filtered_model / included_dir,
                    ignore=shutil.ignore_patterns(*ignored_patterns),
                    dirs_exist_ok=True,
                )

        deps_file = build_dir / TEMP_LOCAL_MODEL_DIR / dependency_file
        shutil.copy(deps_file, filtered_model / dependency_file)

        if deps_lock_file:
            deps_lock_file_full_path = build_dir / TEMP_LOCAL_MODEL_DIR / deps_lock_file
            shutil.copy(deps_lock_file_full_path, filtered_model / deps_lock_file)

        _replace_large_files_with_too_large_file_message(filtered_model, max_bytes)

        zip_path = Path(
            shutil.make_archive(
                base_name=str(filtered_model),
                format="zip",
                root_dir=filtered_model,
            )
        )

        shutil.rmtree(filtered_model)
        return zip_path

    except Exception as e:
        raise QwakGeneralBuildException(
            message="Unable to zip model before upload",
            src_exception=e,
        )


class UploadInChunks(object):
    def __init__(
        self,
        file: Path,
        build_logger: BuildLogger,
        all_files_size_to_upload: int,
        read_so_far: int = 0,
        chunk_size_bytes: int = 1 << 13,
    ):
        self._file = file
        self._chunk_size = chunk_size_bytes
        self._total_size = self._file.stat().st_size
        self._read_so_far = read_so_far
        self._build_logger = build_logger
        self._all_files_size_to_upload = (
            all_files_size_to_upload  # Used for calculating percentage for both files
        )
        self._last_percent_update = 0

    def __iter__(self):
        with self._file.open("rb") as file:
            while True:
                data = file.read(self._chunk_size)
                if not data:
                    break
                self._read_so_far += len(data)
                percent = self._read_so_far * 1e2 / self._all_files_size_to_upload
                msg = "{percent:3.0f}%".format(percent=percent)
                if int(percent / 10) > self._last_percent_update:
                    self._build_logger.info(
                        msg
                    )  # Updating only after 10 percent change
                    self._last_percent_update = int(percent / 10)
                if hasattr(self._build_logger, "spinner_text"):
                    self._build_logger.spinner_text(line=msg)
                yield data

    def __len__(self):
        return self._total_size


def cleaning_up_after_build(step: Step):
    if os.getenv("QWAK_DEBUG") != "true":
        step.build_logger.debug("Removing Qwak temp artifacts directory")
        shutil.rmtree(step.context.host_temp_local_build_dir, ignore_errors=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/deployment/deployment.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from _qwak_proto.qwak.audience.v1 import audience_pb2 as qwak_dot_audience_dot_v1_dot_audience__pb2
from _qwak_proto.qwak.auto_scaling.v1 import auto_scaling_pb2 as qwak_dot_auto__scaling_dot_v1_dot_auto__scaling__pb2
from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n qwak/deployment/deployment.proto\x12\x1aqwak.deployment.management\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fqwak/audience/v1/audience.proto\x1a\'qwak/auto_scaling/v1/auto_scaling.proto\x1a/qwak/user_application/common/v0/resources.proto\"(\n\x1aQwakModeRegistryIdentifier\x12\n\n\x02id\x18\x01 \x01(\t\"\x9e\x01\n\x0eHostingService\x12>\n\tsagemaker\x18\x01 \x01(\x0b\x32%.qwak.deployment.management.SageMakerB\x02\x18\x01H\x00\x12\x45\n\x0fkube_deployment\x18\x02 \x01(\x0b\x32*.qwak.deployment.management.KubeDeploymentH\x00\x42\x05\n\x03val\"\xff\x03\n\x0eKubeDeployment\x12\x15\n\tpod_count\x18\x04 \x01(\x05\x42\x02\x18\x01\x12\x43\n\x0f\x64\x65ployment_size\x18\x05 \x01(\x0b\x32*.qwak.deployment.management.DeploymentSize\x12Z\n\x1b\x61\x64vanced_deployment_options\x18\x06 \x01(\x0b\x32\x35.qwak.deployment.management.AdvancedDeploymentOptions\x12L\n\x14kube_deployment_type\x18\x07 \x01(\x0e\x32..qwak.deployment.management.KubeDeploymentType\x12\x45\n\x10serving_strategy\x18\t \x01(\x0b\x32+.qwak.deployment.management.ServingStrategy\x12\x63\n\x15\x65nvironment_variables\x18\n \x03(\x0b\x32\x44.qwak.deployment.management.KubeDeployment.EnvironmentVariablesEntry\x1a;\n\x19\x45nvironmentVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe8\x01\n\x0fServingStrategy\x12\x45\n\x0frealtime_config\x18\x01 \x01(\x0b\x32*.qwak.deployment.management.RealTimeConfigH\x00\x12\x41\n\rstream_config\x18\x02 \x01(\x0b\x32(.qwak.deployment.management.StreamConfigH\x00\x12?\n\x0c\x62\x61tch_config\x18\x03 \x01(\x0b\x32\'.qwak.deployment.management.BatchConfigH\x00\x42\n\n\x08Strategy\"\x99\x01\n\x0eRealTimeConfig\x12\x41\n\x0etraffic_config\x18\x01 \x01(\x0b\x32).qwak.deployment.management.TrafficConfig\x12\x44\n\x13\x61uto_scaling_config\x18\x02 \x01(\x0b\x32\'.qwak.auto_scaling.v1.AutoScalingConfig\"\xfd\x01\n\rTrafficConfig\x12\x1f\n\x17selected_variation_name\x18\x01 \x01(\t\x12=\n\nvariations\x18\x02 \x03(\x0b\x32%.qwak.deployment.management.VariationB\x02\x18\x01\x12\x46\n\x17\x61udience_routes_entries\x18\x03 \x03(\x0b\x32%.qwak.audience.v1.AudienceRoutesEntry\x12\x1a\n\x12\x66\x61llback_variation\x18\x04 \x01(\t\x12(\n selected_variation_protect_state\x18\x05 \x01(\x08\"F\n\x0cStreamConfig\x12\x36\n\x05kafka\x18\x01 \x01(\x0b\x32\'.qwak.deployment.management.KafkaConfig\"\r\n\x0b\x42\x61tchConfig\"\xaf\x05\n\x0bKafkaConfig\x12\x42\n\x08\x63onsumer\x18\x01 \x01(\x0b\x32\x30.qwak.deployment.management.KafkaConfig.Consumer\x12\x42\n\x08producer\x18\x02 \x01(\x0b\x32\x30.qwak.deployment.management.KafkaConfig.Producer\x12\x0f\n\x07workers\x18\x03 \x01(\x05\x1a\x99\x02\n\x08\x43onsumer\x12\x18\n\x10\x62ootstrap_server\x18\x01 \x03(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\x0f\n\x07timeout\x18\x04 \x01(\x05\x12Y\n\x10\x61uto_offset_type\x18\x05 \x01(\x0e\x32?.qwak.deployment.management.KafkaConfig.Consumer.AutoOffSetType\x12\x16\n\x0emax_batch_size\x18\x06 \x01(\x05\x12\x18\n\x10max_poll_latency\x18\x07 \x01(\x01\"7\n\x0e\x41utoOffSetType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08\x45\x41RLIEST\x10\x01\x12\n\n\x06LATEST\x10\x02\x1a\xea\x01\n\x08Producer\x12\x18\n\x10\x62ootstrap_server\x18\x01 \x03(\t\x12\r\n\x05topic\x18\x02 \x01(\t\x12Z\n\x10\x63ompression_type\x18\x03 \x01(\x0e\x32@.qwak.deployment.management.KafkaConfig.Producer.CompressionType\"Y\n\x0f\x43ompressionType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x10\n\x0cUNCOMPRESSED\x10\x01\x12\x08\n\x04GZIP\x10\x02\x12\n\n\x06SNAPPY\x10\x03\x12\x07\n\x03LZ4\x10\x04\x12\x08\n\x04ZSTD\x10\x05\":\n\tSageMaker\x12\x16\n\x0einstance_count\x18\x04 \x01(\x05\x12\x15\n\rinstance_type\x18\x05 \x01(\t\"\xc2\x02\n\x0e\x44\x65ploymentSize\x12\x16\n\x0enumber_of_pods\x18\x01 \x01(\x05\x12\x0f\n\x03\x63pu\x18\x02 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rmemory_amount\x18\x03 \x01(\x05\x42\x02\x18\x01\x12@\n\x0cmemory_units\x18\x04 \x01(\x0e\x32&.qwak.deployment.management.MemoryUnitB\x02\x18\x01\x12H\n\rgpu_resources\x18\x05 \x01(\x0b\x32-.qwak.user_application.common.v0.GpuResourcesB\x02\x18\x01\x12`\n\x1c\x63lient_pod_compute_resources\x18\x06 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\"Y\n\x0cGpuResources\x12\x35\n\x08gpu_type\x18\x01 \x01(\x0e\x32#.qwak.deployment.management.GpuType\x12\x12\n\ngpu_amount\x18\x02 \x01(\x05\"\xb5\x02\n\x19\x41\x64vancedDeploymentOptions\x12%\n\x1dnumber_of_http_server_workers\x18\x01 \x01(\x05\x12\x1f\n\x17http_request_timeout_ms\x18\x02 \x01(\x05\x12/\n\x0b\x64\x61\x65mon_mode\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1b\n\x13\x63ustom_iam_role_arn\x18\x04 \x01(\t\x12\x16\n\x0emax_batch_size\x18\x05 \x01(\x05\x12(\n deployment_process_timeout_limit\x18\x06 \x01(\x05\x12\x17\n\x0fpurchase_option\x18\x07 \x01(\t\x12\'\n\x1fservice_account_key_secret_name\x18\x08 \x01(\t\"\xb9\n\n\x11\x44\x65ploymentDetails\x12\x31\n\rlast_deployed\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\x08\x62uild_id\x18\x02 \x01(\tH\x00\x12`\n\x1eqwak_model_registry_identifier\x18\x1b \x01(\x0b\x32\x36.qwak.deployment.management.QwakModeRegistryIdentifierH\x00\x12\x16\n\x0enumber_of_pods\x18\x03 \x01(\x05\x12\x14\n\x0c\x63pu_fraction\x18\x04 \x01(\x02\x12\x15\n\rmemory_amount\x18\x05 \x01(\x05\x12<\n\x0cmemory_units\x18\x06 \x01(\x0e\x32&.qwak.deployment.management.MemoryUnit\x12\x19\n\x11number_of_workers\x18\x07 \x01(\x05\x12\x1f\n\x17http_request_timeout_ms\x18\x08 \x01(\x05\x12L\n\x14kube_deployment_type\x18\t \x01(\x0e\x32..qwak.deployment.management.KubeDeploymentType\x12\x45\n\x10serving_strategy\x18\n \x01(\x0b\x32+.qwak.deployment.management.ServingStrategy\x12\x38\n\tvariation\x18\x0b \x01(\x0b\x32%.qwak.deployment.management.Variation\x12\x1b\n\x13\x63ustom_iam_role_arn\x18\x0c \x01(\t\x12\x16\n\x0emax_batch_size\x18\r \x01(\x05\x12:\n\x08gpu_type\x18\x0e \x01(\x0e\x32(.qwak.user_application.common.v0.GpuType\x12\x12\n\ngpu_amount\x18\x0f \x01(\x05\x12\x16\n\x0e\x65nvironment_id\x18\x10 \x01(\t\x12\x1a\n\x12\x61vailable_replicas\x18\x11 \x01(\x05\x12/\n\x0b\x64\x61\x65mon_mode\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12(\n deployment_process_timeout_limit\x18\x13 \x01(\x05\x12\x17\n\x0fpurchase_option\x18\x14 \x01(\t\x12\x66\n\x15\x65nvironment_variables\x18\x15 \x03(\x0b\x32G.qwak.deployment.management.DeploymentDetails.EnvironmentVariablesEntry\x12\x35\n\x11undeployment_time\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x06status\x18\x17 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatus\x12\x15\n\rdeployment_id\x18\x18 \x01(\t\x12M\n\x0f\x66\x61ilure_details\x18\x19 \x01(\x0b\x32\x34.qwak.deployment.management.DeploymentFailureDetails\x12\'\n\x1fservice_account_key_secret_name\x18\x1a \x01(\t\x1a;\n\x19\x45nvironmentVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10image_identifier\"3\n\x18\x44\x65ploymentFailureDetails\x12\x17\n\x0f\x66\x61ilure_message\x18\x01 \x01(\t\"\xb9\x01\n\x19RuntimeDeploymentSettings\x12Y\n\x11root_logger_level\x18\x01 \x01(\x0e\x32>.qwak.deployment.management.RuntimeDeploymentSettings.LogLevel\"A\n\x08LogLevel\x12\x0b\n\x07NOT_SET\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x08\n\x04WARN\x10\x02\x12\x08\n\x04INFO\x10\x03\x12\t\n\x05\x44\x45\x42UG\x10\x04\"\xe6\x03\n\x0f\x44\x65ploymentBrief\x12\x12\n\x08\x62uild_id\x18\x01 \x01(\tH\x00\x12`\n\x1eqwak_model_registry_identifier\x18\x0c \x01(\x0b\x32\x36.qwak.deployment.management.QwakModeRegistryIdentifierH\x00\x12\x41\n\x06status\x18\x02 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatus\x12\x13\n\x0b\x64\x65ployed_by\x18\x03 \x01(\t\x12\x1b\n\x13\x66\x61ilure_reason_code\x18\x04 \x01(\t\x12\x17\n\x0f\x66\x61ilure_message\x18\x05 \x01(\t\x12\x19\n\x11technical_details\x18\x06 \x01(\t\x12\x38\n\x14\x64\x65ployment_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x65nvironment_id\x18\x08 \x01(\t\x12\x16\n\x0evariation_name\x18\t \x01(\t\x12\x1f\n\x17variation_protect_state\x18\n \x01(\x08\x12\x15\n\rdeployment_id\x18\x0b \x01(\tB\x12\n\x10image_identifier\"\xd7\x02\n\x1eKubernetesModelDeploymentState\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x41\n\x06status\x18\x03 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatus\x12\x41\n\x0estatus_details\x18\x04 \x01(\x0b\x32).qwak.deployment.management.StatusDetails\x12\x16\n\x0evariation_name\x18\x05 \x01(\t\x12\x15\n\rdeployment_id\x18\x06 \x01(\t\x12\x12\n\nmodel_uuid\x18\x07 \x01(\t\x12\x43\n\nmanaged_by\x18\x08 \x01(\x0e\x32/.qwak.deployment.management.DeploymentManagedBy\"\x9e\x02\n\rStatusDetails\x12R\n\x16pending_status_details\x18\x01 \x01(\x0b\x32\x30.qwak.deployment.management.PendingStatusDetailsH\x00\x12U\n\x16success_status_details\x18\x02 \x01(\x0b\x32\x33.qwak.deployment.management.SuccessfulStatusDetailsH\x00\x12P\n\x15\x66\x61iled_status_details\x18\x03 \x01(\x0b\x32/.qwak.deployment.management.FailedStatusDetailsH\x00\x42\x10\n\x0estatus_details\"\x9c\x01\n\x14PendingStatusDetails\x12\x41\n\x0cold_instance\x18\x01 \x01(\x0b\x32+.qwak.deployment.management.InstanceDetails\x12\x41\n\x0cnew_instance\x18\x02 \x01(\x0b\x32+.qwak.deployment.management.InstanceDetails\"`\n\x17SuccessfulStatusDetails\x12\x45\n\x10running_instance\x18\x01 \x01(\x0b\x32+.qwak.deployment.management.InstanceDetails\"\xe3\x01\n\x13\x46\x61iledStatusDetails\x12\x43\n\x0f\x66\x61ilure_details\x18\x01 \x01(\x0b\x32*.qwak.deployment.management.FailureDetails\x12\x41\n\x0cold_instance\x18\x02 \x01(\x0b\x32+.qwak.deployment.management.InstanceDetails\x12\x44\n\x0f\x66\x61iled_instance\x18\x03 \x01(\x0b\x32+.qwak.deployment.management.InstanceDetails\"\x91\x01\n\x0e\x46\x61ilureDetails\x12_\n\x1e\x64\x65ployment_failure_reason_code\x18\x01 \x01(\x0e\x32\x37.qwak.deployment.management.DeploymentFailureReasonCode\x12\x1e\n\x16\x66\x61ilure_reason_details\x18\x02 \x01(\t\"\x8f\x01\n\x0fInstanceDetails\x12\x15\n\rdeployment_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x1a\n\x12\x61vailable_replicas\x18\x03 \x01(\x05\x12\x37\n\x04pods\x18\x04 \x03(\x0e\x32).qwak.deployment.management.ModelPodPhase\"a\n\x17\x44\x65ploymentPhasesDetails\x12\x46\n\x11\x64\x65ployment_phases\x18\x01 \x03(\x0b\x32+.qwak.deployment.management.DeploymentPhase\"\xd7\x02\n\x0f\x44\x65ploymentPhase\x12N\n\x15\x64\x65ployment_phase_type\x18\x01 \x01(\x0e\x32/.qwak.deployment.management.DeploymentPhaseType\x12R\n\x17\x64\x65ployment_phase_status\x18\x02 \x01(\x0e\x32\x31.qwak.deployment.management.DeploymentPhaseStatus\x12!\n\x19phase_duration_in_seconds\x18\x03 \x01(\x05\x12.\n\nstarted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x64isplay_message\x18\x06 \x01(\t\"\x88\x01\n\tVariation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x03 \x01(\t\x12:\n\x07traffic\x18\x02 \x01(\x0b\x32\'.qwak.deployment.management.TrafficSpecH\x00\x12\x11\n\tprotected\x18\x04 \x01(\x08\x42\x06\n\x04spec\"4\n\x0bTrafficSpec\x12\x12\n\npercentage\x18\x01 \x01(\x05\x12\x11\n\tis_shadow\x18\x02 \x01(\x08\"]\n\x18\x46utureDeploymentSettings\x12\x41\n\x0etraffic_config\x18\x01 \x01(\x0b\x32).qwak.deployment.management.TrafficConfig\"\xae\x02\n\x1c\x45nvironmentDeploymentMessage\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x12\n\x08\x62uild_id\x18\x03 \x01(\tH\x00\x12`\n\x1eqwak_model_registry_identifier\x18\x06 \x01(\x0b\x32\x36.qwak.deployment.management.QwakModeRegistryIdentifierH\x00\x12\x43\n\x0fhosting_service\x18\x04 \x01(\x0b\x32*.qwak.deployment.management.HostingService\x12\x16\n\nmodel_uuid\x18\x05 \x01(\tB\x02\x18\x01\x42\x12\n\x10image_identifier\"\x92\x01\n\"EnvironmentDeploymentResultMessage\x12\x1b\n\x13\x64\x65ployment_named_id\x18\x01 \x01(\t\x12\x41\n\x06status\x18\x02 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatus\x12\x0c\n\x04info\x18\x03 \x01(\t\"\x90\x02\n\x1e\x45nvironmentUndeploymentMessage\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12V\n\x14hosting_service_type\x18\x03 \x01(\x0e\x32\x38.qwak.deployment.management.DeploymentHostingServiceType\x12\x41\n\x0etraffic_config\x18\x04 \x01(\x0b\x32).qwak.deployment.management.TrafficConfig\x12\x16\n\x0evariation_name\x18\x05 \x01(\t\x12\x12\n\nmodel_uuid\x18\x06 \x01(\t\"w\n$EnvironmentUndeploymentResultMessage\x12\x41\n\x06status\x18\x01 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatus\x12\x0c\n\x04info\x18\x02 \x01(\t\"\xd6\x01\n+EnvironmentRuntimeDeploymentSettingsMessage\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12R\n\x13\x64\x65ployment_settings\x18\x03 \x01(\x0b\x32\x35.qwak.deployment.management.RuntimeDeploymentSettings\x12\x16\n\x0evariation_name\x18\x04 \x01(\t\x12\x12\n\nmodel_uuid\x18\x05 \x01(\t\"G\n1EnvironmentRuntimeDeploymentSettingsResultMessage\x12\x12\n\nerror_info\x18\x01 \x01(\t\"4\n$EnvironmentApplyModelTrafficResponse\x12\x0c\n\x04info\x18\x01 \x01(\t\"\xce\x01\n#EnvironmentDeploymentDetailsMessage\x12J\n\x13\x64\x65ployments_details\x18\x01 \x03(\x0b\x32-.qwak.deployment.management.DeploymentDetails\x12?\n\x10\x61udiences_routes\x18\x02 \x03(\x0b\x32%.qwak.audience.v1.AudienceRoutesEntry\x12\x1a\n\x12\x66\x61llback_variation\x18\x03 \x01(\t\"g\n#EnvironmentDeploymentHistoryMessage\x12@\n\x0b\x64\x65ployments\x18\x01 \x03(\x0b\x32+.qwak.deployment.management.DeploymentBrief\"V\n\x19\x45nvironmentTrafficMessage\x12\x39\n\nvariations\x18\x01 \x03(\x0b\x32%.qwak.deployment.management.Variation\"\x9e\x02\n BuildDeploymentEnvironmentStatus\x12\x87\x01\n\x1f\x65nvironment_to_deployment_brief\x18\x01 \x03(\x0b\x32^.qwak.deployment.management.BuildDeploymentEnvironmentStatus.EnvironmentToDeploymentBriefEntry\x1ap\n!EnvironmentToDeploymentBriefEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qwak.deployment.management.DeploymentBrief:\x02\x38\x01\"S\n\x15\x42uildDeploymentStatus\x12\x12\n\nbuild_uuid\x18\x01 \x01(\t\x12\x13\n\x0bis_deployed\x18\x02 \x01(\x08\x12\x11\n\tis_in_use\x18\x03 \x01(\x08\"]\n\x1d\x43\x61ncelDeploymentRequestStatus\x12%\n\x1d\x63\x61ncel_requested_successfully\x18\x01 \x01(\x08\x12\x15\n\rerror_message\x18\x02 \x01(\t*\x85\x03\n\x15ModelDeploymentStatus\x12\x16\n\x12INVALID_DEPLOYMENT\x10\x00\x12\x19\n\x15INITIATING_DEPLOYMENT\x10\x01\x12 \n\x1c\x46\x41ILED_INITIATING_DEPLOYMENT\x10\x08\x12\x16\n\x12PENDING_DEPLOYMENT\x10\x02\x12\x19\n\x15SUCCESSFUL_DEPLOYMENT\x10\x03\x12\x15\n\x11\x46\x41ILED_DEPLOYMENT\x10\x04\x12\x1b\n\x17INITIATING_UNDEPLOYMENT\x10\t\x12\x18\n\x14PENDING_UNDEPLOYMENT\x10\n\x12\x1b\n\x17SUCCESSFUL_UNDEPLOYMENT\x10\x05\x12\x17\n\x13\x46\x41ILED_UNDEPLOYMENT\x10\x06\x12\t\n\x05UNSET\x10\x07\x12\x19\n\x15\x41LL_BUILDS_UNDEPLOYED\x10\x0b\x12\x18\n\x14\x43\x41NCELLED_DEPLOYMENT\x10\x0c\x12 \n\x1cINITIATING_CANCEL_DEPLOYMENT\x10\r*O\n\x1c\x44\x65ploymentHostingServiceType\x12\x0b\n\x07INVALID\x10\x00\x12\r\n\tSAGEMAKER\x10\x01\x12\x13\n\x0fKUBE_DEPLOYMENT\x10\x02*F\n\x12KubeDeploymentType\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06ONLINE\x10\x01\x12\n\n\x06STREAM\x10\x02\x12\t\n\x05\x42\x41TCH\x10\x03*{\n\x07GpuType\x12\x0f\n\x0bINVALID_GPU\x10\x00\x12\x0e\n\nNVIDIA_K80\x10\x01\x12\x0f\n\x0bNVIDIA_V100\x10\x02\x12\x0f\n\x0bNVIDIA_A100\x10\x03\x12\r\n\tNVIDIA_T4\x10\x04\x12\x0f\n\x0bNVIDIA_A10G\x10\x05\x12\r\n\tNVIDIA_L4\x10\x06*+\n\nMemoryUnit\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02*\x83\x01\n\x13\x44\x65ploymentManagedBy\x12!\n\x1d\x44\x45PLOYMENT_MANAGED_BY_INVALID\x10\x00\x12&\n\"DEPLOYMENT_MANAGED_BY_KUBE_CAPTAIN\x10\x01\x12!\n\x1d\x44\x45PLOYMENT_MANAGED_BY_ADMIRAL\x10\x02*\x93\x02\n\x1b\x44\x65ploymentFailureReasonCode\x12\x18\n\x14INVALID_FAILURE_CODE\x10\x00\x12\x12\n\x0eUNKNOWN_REASON\x10\x01\x12\x1e\n\x1aNO_REPLICA_SETS_PODS_FOUND\x10\x02\x12\x1d\n\x19MODEL_CONTAINER_NOT_FOUND\x10\x03\x12\x11\n\rUNSCHEDULABLE\x10\x04\x12\x1a\n\x16\x44OCKER_IMAGE_NOT_FOUND\x10\x05\x12\x19\n\x15MEMORY_LIMIT_EXCEEDED\x10\x06\x12\x0e\n\nCRASH_LOOP\x10\x07\x12-\n)CONTAINER_FAIL_TO_LOAD_FOR_UNKNOWN_REASON\x10\x08*\xb7\x01\n\rModelPodPhase\x12\x15\n\x11INVALID_POD_PHASE\x10\x00\x12)\n%MODEL_POD_PHASE_PROVISIONING_INSTANCE\x10\x01\x12!\n\x1dMODEL_POD_PHASE_PULLING_IMAGE\x10\x02\x12&\n\"MODEL_POD_PHASE_INITIALIZING_MODEL\x10\x03\x12\x19\n\x15MODEL_POD_PHASE_READY\x10\x04*\xac\x01\n\x13\x44\x65ploymentPhaseType\x12\x1c\n\x18INVALID_DEPLOYMENT_PHASE\x10\x00\x12*\n&DEPLOYMENT_PHASE_PROVISIONING_INSTANCE\x10\x01\x12\"\n\x1e\x44\x45PLOYMENT_PHASE_PULLING_IMAGE\x10\x02\x12\'\n#DEPLOYMENT_PHASE_INITIALIZING_MODEL\x10\x03*\xf5\x01\n\x15\x44\x65ploymentPhaseStatus\x12#\n\x1fINVALID_DEPLOYMENT_PHASE_STATUS\x10\x00\x12 \n\x1c\x44\x45PLOYMENT_PHASE_NOT_STARTED\x10\x01\x12\x1c\n\x18\x44\x45PLOYMENT_PHASE_STARTED\x10\x02\x12\x1d\n\x19\x44\x45PLOYMENT_PHASE_FINISHED\x10\x03\x12\x1d\n\x19\x44\x45PLOYMENT_PHASE_CANCELED\x10\x04\x12\x1b\n\x17\x44\x45PLOYMENT_PHASE_FAILED\x10\x05\x12\x1c\n\x18\x44\x45PLOYMENT_PHASE_ABORTED\x10\x06\x42\x45\n%com.qwak.ai.management.deployment.apiP\x01Z\x1aqwak/deployment;deploymentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.deployment.deployment_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.management.deployment.apiP\001Z\032qwak/deployment;deployment'
  _HOSTINGSERVICE.fields_by_name['sagemaker']._options = None
  _HOSTINGSERVICE.fields_by_name['sagemaker']._serialized_options = b'\030\001'
  _KUBEDEPLOYMENT_ENVIRONMENTVARIABLESENTRY._options = None
  _KUBEDEPLOYMENT_ENVIRONMENTVARIABLESENTRY._serialized_options = b'8\001'
  _KUBEDEPLOYMENT.fields_by_name['pod_count']._options = None
  _KUBEDEPLOYMENT.fields_by_name['pod_count']._serialized_options = b'\030\001'
  _TRAFFICCONFIG.fields_by_name['variations']._options = None
  _TRAFFICCONFIG.fields_by_name['variations']._serialized_options = b'\030\001'
  _DEPLOYMENTSIZE.fields_by_name['cpu']._options = None
  _DEPLOYMENTSIZE.fields_by_name['cpu']._serialized_options = b'\030\001'
  _DEPLOYMENTSIZE.fields_by_name['memory_amount']._options = None
  _DEPLOYMENTSIZE.fields_by_name['memory_amount']._serialized_options = b'\030\001'
  _DEPLOYMENTSIZE.fields_by_name['memory_units']._options = None
  _DEPLOYMENTSIZE.fields_by_name['memory_units']._serialized_options = b'\030\001'
  _DEPLOYMENTSIZE.fields_by_name['gpu_resources']._options = None
  _DEPLOYMENTSIZE.fields_by_name['gpu_resources']._serialized_options = b'\030\001'
  _DEPLOYMENTDETAILS_ENVIRONMENTVARIABLESENTRY._options = None
  _DEPLOYMENTDETAILS_ENVIRONMENTVARIABLESENTRY._serialized_options = b'8\001'
  _KUBERNETESMODELDEPLOYMENTSTATE.fields_by_name['branch_id']._options = None
  _KUBERNETESMODELDEPLOYMENTSTATE.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _ENVIRONMENTDEPLOYMENTMESSAGE.fields_by_name['branch_id']._options = None
  _ENVIRONMENTDEPLOYMENTMESSAGE.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _ENVIRONMENTDEPLOYMENTMESSAGE.fields_by_name['model_uuid']._options = None
  _ENVIRONMENTDEPLOYMENTMESSAGE.fields_by_name['model_uuid']._serialized_options = b'\030\001'
  _ENVIRONMENTUNDEPLOYMENTMESSAGE.fields_by_name['branch_id']._options = None
  _ENVIRONMENTUNDEPLOYMENTMESSAGE.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _ENVIRONMENTRUNTIMEDEPLOYMENTSETTINGSMESSAGE.fields_by_name['branch_id']._options = None
  _ENVIRONMENTRUNTIMEDEPLOYMENTSETTINGSMESSAGE.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _BUILDDEPLOYMENTENVIRONMENTSTATUS_ENVIRONMENTTODEPLOYMENTBRIEFENTRY._options = None
  _BUILDDEPLOYMENTENVIRONMENTSTATUS_ENVIRONMENTTODEPLOYMENTBRIEFENTRY._serialized_options = b'8\001'
  _globals['_MODELDEPLOYMENTSTATUS']._serialized_start=9466
  _globals['_MODELDEPLOYMENTSTATUS']._serialized_end=9855
  _globals['_DEPLOYMENTHOSTINGSERVICETYPE']._serialized_start=9857
  _globals['_DEPLOYMENTHOSTINGSERVICETYPE']._serialized_end=9936
  _globals['_KUBEDEPLOYMENTTYPE']._serialized_start=9938
  _globals['_KUBEDEPLOYMENTTYPE']._serialized_end=10008
  _globals['_GPUTYPE']._serialized_start=10010
  _globals['_GPUTYPE']._serialized_end=10133
  _globals['_MEMORYUNIT']._serialized_start=10135
  _globals['_MEMORYUNIT']._serialized_end=10178
  _globals['_DEPLOYMENTMANAGEDBY']._serialized_start=10181
  _globals['_DEPLOYMENTMANAGEDBY']._serialized_end=10312
  _globals['_DEPLOYMENTFAILUREREASONCODE']._serialized_start=10315
  _globals['_DEPLOYMENTFAILUREREASONCODE']._serialized_end=10590
  _globals['_MODELPODPHASE']._serialized_start=10593
  _globals['_MODELPODPHASE']._serialized_end=10776
  _globals['_DEPLOYMENTPHASETYPE']._serialized_start=10779
  _globals['_DEPLOYMENTPHASETYPE']._serialized_end=10951
  _globals['_DEPLOYMENTPHASESTATUS']._serialized_start=10954
  _globals['_DEPLOYMENTPHASESTATUS']._serialized_end=11199
  _globals['_QWAKMODEREGISTRYIDENTIFIER']._serialized_start=252
  _globals['_QWAKMODEREGISTRYIDENTIFIER']._serialized_end=292
  _globals['_HOSTINGSERVICE']._serialized_start=295
  _globals['_HOSTINGSERVICE']._serialized_end=453
  _globals['_KUBEDEPLOYMENT']._serialized_start=456
  _globals['_KUBEDEPLOYMENT']._serialized_end=967
  _globals['_KUBEDEPLOYMENT_ENVIRONMENTVARIABLESENTRY']._serialized_start=908
  _globals['_KUBEDEPLOYMENT_ENVIRONMENTVARIABLESENTRY']._serialized_end=967
  _globals['_SERVINGSTRATEGY']._serialized_start=970
  _globals['_SERVINGSTRATEGY']._serialized_end=1202
  _globals['_REALTIMECONFIG']._serialized_start=1205
  _globals['_REALTIMECONFIG']._serialized_end=1358
  _globals['_TRAFFICCONFIG']._serialized_start=1361
  _globals['_TRAFFICCONFIG']._serialized_end=1614
  _globals['_STREAMCONFIG']._serialized_start=1616
  _globals['_STREAMCONFIG']._serialized_end=1686
  _globals['_BATCHCONFIG']._serialized_start=1688
  _globals['_BATCHCONFIG']._serialized_end=1701
  _globals['_KAFKACONFIG']._serialized_start=1704
  _globals['_KAFKACONFIG']._serialized_end=2391
  _globals['_KAFKACONFIG_CONSUMER']._serialized_start=1873
  _globals['_KAFKACONFIG_CONSUMER']._serialized_end=2154
  _globals['_KAFKACONFIG_CONSUMER_AUTOOFFSETTYPE']._serialized_start=2099
  _globals['_KAFKACONFIG_CONSUMER_AUTOOFFSETTYPE']._serialized_end=2154
  _globals['_KAFKACONFIG_PRODUCER']._serialized_start=2157
  _globals['_KAFKACONFIG_PRODUCER']._serialized_end=2391
  _globals['_KAFKACONFIG_PRODUCER_COMPRESSIONTYPE']._serialized_start=2302
  _globals['_KAFKACONFIG_PRODUCER_COMPRESSIONTYPE']._serialized_end=2391
  _globals['_SAGEMAKER']._serialized_start=2393
  _globals['_SAGEMAKER']._serialized_end=2451
  _globals['_DEPLOYMENTSIZE']._serialized_start=2454
  _globals['_DEPLOYMENTSIZE']._serialized_end=2776
  _globals['_GPURESOURCES']._serialized_start=2778
  _globals['_GPURESOURCES']._serialized_end=2867
  _globals['_ADVANCEDDEPLOYMENTOPTIONS']._serialized_start=2870
  _globals['_ADVANCEDDEPLOYMENTOPTIONS']._serialized_end=3179
  _globals['_DEPLOYMENTDETAILS']._serialized_start=3182
  _globals['_DEPLOYMENTDETAILS']._serialized_end=4519
  _globals['_DEPLOYMENTDETAILS_ENVIRONMENTVARIABLESENTRY']._serialized_start=908
  _globals['_DEPLOYMENTDETAILS_ENVIRONMENTVARIABLESENTRY']._serialized_end=967
  _globals['_DEPLOYMENTFAILUREDETAILS']._serialized_start=4521
  _globals['_DEPLOYMENTFAILUREDETAILS']._serialized_end=4572
  _globals['_RUNTIMEDEPLOYMENTSETTINGS']._serialized_start=4575
  _globals['_RUNTIMEDEPLOYMENTSETTINGS']._serialized_end=4760
  _globals['_RUNTIMEDEPLOYMENTSETTINGS_LOGLEVEL']._serialized_start=4695
  _globals['_RUNTIMEDEPLOYMENTSETTINGS_LOGLEVEL']._serialized_end=4760
  _globals['_DEPLOYMENTBRIEF']._serialized_start=4763
  _globals['_DEPLOYMENTBRIEF']._serialized_end=5249
  _globals['_KUBERNETESMODELDEPLOYMENTSTATE']._serialized_start=5252
  _globals['_KUBERNETESMODELDEPLOYMENTSTATE']._serialized_end=5595
  _globals['_STATUSDETAILS']._serialized_start=5598
  _globals['_STATUSDETAILS']._serialized_end=5884
  _globals['_PENDINGSTATUSDETAILS']._serialized_start=5887
  _globals['_PENDINGSTATUSDETAILS']._serialized_end=6043
  _globals['_SUCCESSFULSTATUSDETAILS']._serialized_start=6045
  _globals['_SUCCESSFULSTATUSDETAILS']._serialized_end=6141
  _globals['_FAILEDSTATUSDETAILS']._serialized_start=6144
  _globals['_FAILEDSTATUSDETAILS']._serialized_end=6371
  _globals['_FAILUREDETAILS']._serialized_start=6374
  _globals['_FAILUREDETAILS']._serialized_end=6519
  _globals['_INSTANCEDETAILS']._serialized_start=6522
  _globals['_INSTANCEDETAILS']._serialized_end=6665
  _globals['_DEPLOYMENTPHASESDETAILS']._serialized_start=6667
  _globals['_DEPLOYMENTPHASESDETAILS']._serialized_end=6764
  _globals['_DEPLOYMENTPHASE']._serialized_start=6767
  _globals['_DEPLOYMENTPHASE']._serialized_end=7110
  _globals['_VARIATION']._serialized_start=7113
  _globals['_VARIATION']._serialized_end=7249
  _globals['_TRAFFICSPEC']._serialized_start=7251
  _globals['_TRAFFICSPEC']._serialized_end=7303
  _globals['_FUTUREDEPLOYMENTSETTINGS']._serialized_start=7305
  _globals['_FUTUREDEPLOYMENTSETTINGS']._serialized_end=7398
  _globals['_ENVIRONMENTDEPLOYMENTMESSAGE']._serialized_start=7401
  _globals['_ENVIRONMENTDEPLOYMENTMESSAGE']._serialized_end=7703
  _globals['_ENVIRONMENTDEPLOYMENTRESULTMESSAGE']._serialized_start=7706
  _globals['_ENVIRONMENTDEPLOYMENTRESULTMESSAGE']._serialized_end=7852
  _globals['_ENVIRONMENTUNDEPLOYMENTMESSAGE']._serialized_start=7855
  _globals['_ENVIRONMENTUNDEPLOYMENTMESSAGE']._serialized_end=8127
  _globals['_ENVIRONMENTUNDEPLOYMENTRESULTMESSAGE']._serialized_start=8129
  _globals['_ENVIRONMENTUNDEPLOYMENTRESULTMESSAGE']._serialized_end=8248
  _globals['_ENVIRONMENTRUNTIMEDEPLOYMENTSETTINGSMESSAGE']._serialized_start=8251
  _globals['_ENVIRONMENTRUNTIMEDEPLOYMENTSETTINGSMESSAGE']._serialized_end=8465
  _globals['_ENVIRONMENTRUNTIMEDEPLOYMENTSETTINGSRESULTMESSAGE']._serialized_start=8467
  _globals['_ENVIRONMENTRUNTIMEDEPLOYMENTSETTINGSRESULTMESSAGE']._serialized_end=8538
  _globals['_ENVIRONMENTAPPLYMODELTRAFFICRESPONSE']._serialized_start=8540
  _globals['_ENVIRONMENTAPPLYMODELTRAFFICRESPONSE']._serialized_end=8592
  _globals['_ENVIRONMENTDEPLOYMENTDETAILSMESSAGE']._serialized_start=8595
  _globals['_ENVIRONMENTDEPLOYMENTDETAILSMESSAGE']._serialized_end=8801
  _globals['_ENVIRONMENTDEPLOYMENTHISTORYMESSAGE']._serialized_start=8803
  _globals['_ENVIRONMENTDEPLOYMENTHISTORYMESSAGE']._serialized_end=8906
  _globals['_ENVIRONMENTTRAFFICMESSAGE']._serialized_start=8908
  _globals['_ENVIRONMENTTRAFFICMESSAGE']._serialized_end=8994
  _globals['_BUILDDEPLOYMENTENVIRONMENTSTATUS']._serialized_start=8997
  _globals['_BUILDDEPLOYMENTENVIRONMENTSTATUS']._serialized_end=9283
  _globals['_BUILDDEPLOYMENTENVIRONMENTSTATUS_ENVIRONMENTTODEPLOYMENTBRIEFENTRY']._serialized_start=9171
  _globals['_BUILDDEPLOYMENTENVIRONMENTSTATUS_ENVIRONMENTTODEPLOYMENTBRIEFENTRY']._serialized_end=9283
  _globals['_BUILDDEPLOYMENTSTATUS']._serialized_start=9285
  _globals['_BUILDDEPLOYMENTSTATUS']._serialized_end=9368
  _globals['_CANCELDEPLOYMENTREQUESTSTATUS']._serialized_start=9370
  _globals['_CANCELDEPLOYMENTREQUESTSTATUS']._serialized_end=9463
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CloudProvider:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CloudProviderEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CloudProvider.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CLOUD_PROVIDER_INVALID: _CloudProvider.ValueType  # 0
    AWS: _CloudProvider.ValueType  # 1
    GCP: _CloudProvider.ValueType  # 2

class CloudProvider(_CloudProvider, metaclass=_CloudProviderEnumTypeWrapper): ...

CLOUD_PROVIDER_INVALID: CloudProvider.ValueType  # 0
AWS: CloudProvider.ValueType  # 1
GCP: CloudProvider.ValueType  # 2
global___CloudProvider = CloudProvider

class _CreateAccountRequestStatusCode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CreateAccountRequestStatusCodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CreateAccountRequestStatusCode.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CREATE_ACCOUNT_REQUEST_STATUS_CODE_INVALID: _CreateAccountRequestStatusCode.ValueType  # 0
    REQUEST_PENDING: _CreateAccountRequestStatusCode.ValueType  # 1
    """Waiting for creation"""
    REQUEST_REGISTERED: _CreateAccountRequestStatusCode.ValueType  # 2
    """Account successfully registered"""
    REQUEST_PROCESSING: _CreateAccountRequestStatusCode.ValueType  # 3
    """Creation in progress"""
    REQUEST_FAILED: _CreateAccountRequestStatusCode.ValueType  # 4
    """Account failed to registered"""

class CreateAccountRequestStatusCode(_CreateAccountRequestStatusCode, metaclass=_CreateAccountRequestStatusCodeEnumTypeWrapper): ...

CREATE_ACCOUNT_REQUEST_STATUS_CODE_INVALID: CreateAccountRequestStatusCode.ValueType  # 0
REQUEST_PENDING: CreateAccountRequestStatusCode.ValueType  # 1
"""Waiting for creation"""
REQUEST_REGISTERED: CreateAccountRequestStatusCode.ValueType  # 2
"""Account successfully registered"""
REQUEST_PROCESSING: CreateAccountRequestStatusCode.ValueType  # 3
"""Creation in progress"""
REQUEST_FAILED: CreateAccountRequestStatusCode.ValueType  # 4
"""Account failed to registered"""
global___CreateAccountRequestStatusCode = CreateAccountRequestStatusCode

class CloudProviderAWS(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CloudProviderAWS = CloudProviderAWS

class CloudProviderGCP(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CloudProviderGCP = CloudProviderGCP

class CloudProviderSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AWS_FIELD_NUMBER: builtins.int
    GCP_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    @property
    def aws(self) -> global___CloudProviderAWS: ...
    @property
    def gcp(self) -> global___CloudProviderGCP: ...
    region: builtins.str
    """Region"""
    def __init__(
        self,
        *,
        aws: global___CloudProviderAWS | None = ...,
        gcp: global___CloudProviderGCP | None = ...,
        region: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws", b"aws", "cloud_provider", b"cloud_provider", "gcp", b"gcp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws", b"aws", "cloud_provider", b"cloud_provider", "gcp", b"gcp", "region", b"region"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["cloud_provider", b"cloud_provider"]) -> typing_extensions.Literal["aws", "gcp"] | None: ...

global___CloudProviderSpec = CloudProviderSpec

class CreateAccountOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    CLOUD_PROVIDER_FIELD_NUMBER: builtins.int
    CLOUD_PROVIDER_SPEC_FIELD_NUMBER: builtins.int
    JFROG_TENANT_SPEC_FIELD_NUMBER: builtins.int
    CLUSTER_IDENTIFIER_FIELD_NUMBER: builtins.int
    account_name: builtins.str
    """Account name"""
    cloud_provider: global___CloudProvider.ValueType
    """Cluster provider"""
    @property
    def cloud_provider_spec(self) -> global___CloudProviderSpec:
        """Cloud provider spec"""
    @property
    def jfrog_tenant_spec(self) -> global___SelfServiceJFrogTenantSpec:
        """JFrog tenant spec"""
    @property
    def cluster_identifier(self) -> global___ClusterIdentifier:
        """Cluster identifier"""
    def __init__(
        self,
        *,
        account_name: builtins.str = ...,
        cloud_provider: global___CloudProvider.ValueType = ...,
        cloud_provider_spec: global___CloudProviderSpec | None = ...,
        jfrog_tenant_spec: global___SelfServiceJFrogTenantSpec | None = ...,
        cluster_identifier: global___ClusterIdentifier | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_provider_spec", b"cloud_provider_spec", "cluster_identifier", b"cluster_identifier", "jfrog_tenant_spec", b"jfrog_tenant_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_name", b"account_name", "cloud_provider", b"cloud_provider", "cloud_provider_spec", b"cloud_provider_spec", "cluster_identifier", b"cluster_identifier", "jfrog_tenant_spec", b"jfrog_tenant_spec"]) -> None: ...

global___CreateAccountOptions = CreateAccountOptions

class ClusterIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    @property
    def cluster_id(self) -> global___ClusterIdIdentifier: ...
    def __init__(
        self,
        *,
        cluster_id: global___ClusterIdIdentifier | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["cluster_id"] | None: ...

global___ClusterIdentifier = ClusterIdentifier

class ClusterIdIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___ClusterIdIdentifier = ClusterIdIdentifier

class CreateAccountRequestDescription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> global___CreateAccountRequestMetadata:
        """Metadata of the account creation request"""
    @property
    def spec(self) -> global___CreateAccountRequestSpec:
        """Spec of the account creation request"""
    @property
    def status(self) -> global___CreateAccountRequestStatus:
        """Status of the account creation request"""
    def __init__(
        self,
        *,
        metadata: global___CreateAccountRequestMetadata | None = ...,
        spec: global___CreateAccountRequestSpec | None = ...,
        status: global___CreateAccountRequestStatus | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "spec", b"spec", "status", b"status"]) -> None: ...

global___CreateAccountRequestDescription = CreateAccountRequestDescription

class CreateAccountRequestMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    REQUESTED_BY_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Id of the request"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Created at"""
    requested_by: builtins.str
    """The user id of the requesting user"""
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        requested_by: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "request_id", b"request_id", "requested_by", b"requested_by"]) -> None: ...

global___CreateAccountRequestMetadata = CreateAccountRequestMetadata

class CreateAccountRequestSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    account_name: builtins.str
    """The requested account name"""
    def __init__(
        self,
        *,
        account_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_name", b"account_name"]) -> None: ...

global___CreateAccountRequestSpec = CreateAccountRequestSpec

class CreateAccountRequestStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    LAST_CHANGED_AT_FIELD_NUMBER: builtins.int
    code: global___CreateAccountRequestStatusCode.ValueType
    """Status code"""
    @property
    def last_changed_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When the status has been changed"""
    def __init__(
        self,
        *,
        code: global___CreateAccountRequestStatusCode.ValueType = ...,
        last_changed_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_changed_at", b"last_changed_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "last_changed_at", b"last_changed_at"]) -> None: ...

global___CreateAccountRequestStatus = CreateAccountRequestStatus

class CloudProviderRegions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_PROVIDER_FIELD_NUMBER: builtins.int
    REGIONS_FIELD_NUMBER: builtins.int
    cloud_provider: global___CloudProvider.ValueType
    """Cloud provider"""
    @property
    def regions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Region"""
    def __init__(
        self,
        *,
        cloud_provider: global___CloudProvider.ValueType = ...,
        regions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_provider", b"cloud_provider", "regions", b"regions"]) -> None: ...

global___CloudProviderRegions = CloudProviderRegions

class SelfServiceJFrogProjectSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_KEY_FIELD_NUMBER: builtins.int
    project_key: builtins.str
    """The JFrog project's key"""
    def __init__(
        self,
        *,
        project_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["project_key", b"project_key"]) -> None: ...

global___SelfServiceJFrogProjectSpec = SelfServiceJFrogProjectSpec

class SelfServiceJFrogTenantSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_PROJECT_SPEC_FIELD_NUMBER: builtins.int
    @property
    def default_project_spec(self) -> global___SelfServiceJFrogProjectSpec:
        """Default project spec"""
    def __init__(
        self,
        *,
        default_project_spec: global___SelfServiceJFrogProjectSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_project_spec", b"default_project_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_project_spec", b"default_project_spec"]) -> None: ...

global___SelfServiceJFrogTenantSpec = SelfServiceJFrogTenantSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.creds.secret_pb2
import qwak.administration.runtime_configuration.v0.external.databricks.auth_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AzureAuthentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AZURE_DATABRICKS_AUTH_FIELD_NUMBER: builtins.int
    @property
    def azure_databricks_auth(self) -> global___AzureDatabricksServiceAuthentication: ...
    def __init__(
        self,
        *,
        azure_databricks_auth: global___AzureDatabricksServiceAuthentication | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_databricks_auth", b"azure_databricks_auth", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_databricks_auth", b"azure_databricks_auth", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["azure_databricks_auth"] | None: ...

global___AzureAuthentication = AzureAuthentication

class AzureDatabricksServiceAuthentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DB_AUTH_FIELD_NUMBER: builtins.int
    AZURE_BLOB_STORAGE_AUTH_FIELD_NUMBER: builtins.int
    @property
    def db_auth(self) -> qwak.administration.runtime_configuration.v0.external.databricks.auth_pb2.DatabricksAuth: ...
    @property
    def azure_blob_storage_auth(self) -> global___AzureBlobStorageAuth: ...
    def __init__(
        self,
        *,
        db_auth: qwak.administration.runtime_configuration.v0.external.databricks.auth_pb2.DatabricksAuth | None = ...,
        azure_blob_storage_auth: global___AzureBlobStorageAuth | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_blob_storage_auth", b"azure_blob_storage_auth", "db_auth", b"db_auth"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_blob_storage_auth", b"azure_blob_storage_auth", "db_auth", b"db_auth"]) -> None: ...

global___AzureDatabricksServiceAuthentication = AzureDatabricksServiceAuthentication

class AzureBlobStorageAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SAS_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def sas_token(self) -> global___AzureSASToken: ...
    def __init__(
        self,
        *,
        sas_token: global___AzureSASToken | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "sas_token", b"sas_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "sas_token", b"sas_token"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth_type", b"auth_type"]) -> typing_extensions.Literal["sas_token"] | None: ...

global___AzureBlobStorageAuth = AzureBlobStorageAuth

class AzureSASToken(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_FIELD_NUMBER: builtins.int
    @property
    def secret(self) -> qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef: ...
    def __init__(
        self,
        *,
        secret: qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["location", b"location", "secret", b"secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "secret", b"secret"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["location", b"location"]) -> typing_extensions.Literal["secret"] | None: ...

global___AzureSASToken = AzureSASToken



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/automation/v1/automation_execution.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-qwak/automation/v1/automation_execution.proto\x12\x12qwak.automation.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"w\n\x1a\x41utomationExecutionMessage\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x43\n\x0brun_details\x18\x02 \x01(\x0b\x32..qwak.automation.v1.ExecutionRunDetailsMessage\"\xa7\x02\n\x1a\x45xecutionRunDetailsMessage\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rerror_details\x18\x03 \x01(\t\x12:\n\x06status\x18\x04 \x01(\x0e\x32*.qwak.automation.v1.ExecutionStatusMessage\x12\x0c\n\x04task\x18\x05 \x01(\t\x12\x14\n\x0c\x66inish_cause\x18\x06 \x01(\t\x12\x34\n\x10last_update_date\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"i\n\tDateRange\x12.\n\nstart_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp*P\n\x16\x45xecutionStatusMessage\x12\r\n\tUNDEFINED\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\x0e\n\nSUCCESSFUL\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x42!\n\x1d\x63om.qwak.ai.automation.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.automation.v1.automation_execution_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.automation.api.v1P\001'
  _globals['_EXECUTIONSTATUSMESSAGE']._serialized_start=628
  _globals['_EXECUTIONSTATUSMESSAGE']._serialized_end=708
  _globals['_AUTOMATIONEXECUTIONMESSAGE']._serialized_start=102
  _globals['_AUTOMATIONEXECUTIONMESSAGE']._serialized_end=221
  _globals['_EXECUTIONRUNDETAILSMESSAGE']._serialized_start=224
  _globals['_EXECUTIONRUNDETAILSMESSAGE']._serialized_end=519
  _globals['_DATERANGE']._serialized_start=521
  _globals['_DATERANGE']._serialized_end=626
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod
from dataclasses import dataclass
from datetime import datetime
from typing import List, Optional

from _qwak_proto.qwak.execution.v1.backfill_pb2 import (
    AsScheduledBackfillType as ProtoAsScheduledBackfillType,
    BackfillSpec as ProtoBackfillSpec,
    BackfillType as ProtoBackfillType,
    ExplicitResourceConfiguration as ProtoExplicitResourceConfiguration,
    FullResetBackfillWindow as ProtoFullResetBackfillWindow,
    ImplicitResourceConfiguration as ProtoImplicitResourceConfiguration,
    IntervalBackfillWindow as ProtoIntervalBackfillWindow,
)
from google.protobuf.timestamp_pb2 import Timestamp as ProtoTimetamp
from qwak.clients.feature_store.execution_management_client import (
    ExecutionManagementClient,
)
from qwak.exceptions import QwakException
from qwak.feature_store.feature_sets.execution_spec import ClusterTemplate


@dataclass()
class IntervalBackfillWindow:
    @staticmethod
    def to_proto(
        backfill_start: datetime, backfill_end: datetime
    ) -> ProtoIntervalBackfillWindow:
        proto_backfill_start_timestamp = ProtoTimetamp()
        proto_backfill_start_timestamp.FromDatetime(backfill_start)

        proto_backfill_end_timestamp = ProtoTimetamp()
        proto_backfill_end_timestamp.FromDatetime(backfill_end)

        return ProtoIntervalBackfillWindow(
            backfill_start=proto_backfill_start_timestamp,
            backfill_end=proto_backfill_end_timestamp,
        )


@dataclass()
class FullResetBackfillWindow:
    @staticmethod
    def to_proto() -> Optional[ProtoFullResetBackfillWindow]:
        return ProtoFullResetBackfillWindow()


@dataclass()
class ImplicitResourceConfiguration:
    @staticmethod
    def to_proto() -> ProtoImplicitResourceConfiguration:
        return ProtoImplicitResourceConfiguration()


@dataclass()
class ExplicitResourceConfiguration:
    @staticmethod
    def _get_cluster_template(cluster_template_str: str) -> Optional[ClusterTemplate]:
        if cluster_template_str:
            try:
                return ClusterTemplate(cluster_template_str.upper())
            except ValueError:
                raise QwakException(
                    f"Received an unsupported cluster template size {cluster_template_str.upper()}"
                )
        return None

    @classmethod
    def to_proto(cls, cluster_template_str: str) -> ProtoImplicitResourceConfiguration:
        cluster_template = cls._get_cluster_template(cluster_template_str)
        return ProtoExplicitResourceConfiguration(
            cluster_template=ClusterTemplate.to_proto(cluster_template)
        )


@dataclass()
class BackfillType(ABC):
    @staticmethod
    @abstractmethod
    def to_proto() -> ProtoBackfillType:
        pass


@dataclass()
class AsScheduledBackfillType(BackfillType):
    @staticmethod
    def to_proto() -> ProtoBackfillType:
        return ProtoBackfillType(as_scheduled=ProtoAsScheduledBackfillType())


@dataclass()
class Backfill:
    def __init__(
        self,
        featureset_name: str,
        start_time: Optional[datetime] = None,
        stop_time: Optional[datetime] = None,
        cluster_template: str = "",
        comment: str = "",
    ):
        self._execution_management_client = self._get_execution_management_client()
        self.featureset_name = featureset_name
        self.start_time = start_time
        self.stop_time = stop_time
        self.cluster_template = cluster_template
        self.comment = comment

    @staticmethod
    def _get_execution_management_client() -> ExecutionManagementClient:
        return ExecutionManagementClient()

    def _generate_backfill_spec_proto(self) -> ProtoBackfillSpec:
        explicit_configuration: Optional[ProtoExplicitResourceConfiguration] = None
        no_override: Optional[ProtoImplicitResourceConfiguration] = None
        interval_backfill: Optional[ProtoIntervalBackfillWindow] = None
        full_reset_backfill: Optional[ProtoFullResetBackfillWindow] = None
        backfill_type: ProtoBackfillType = AsScheduledBackfillType.to_proto()

        if self.cluster_template:
            explicit_configuration = ExplicitResourceConfiguration.to_proto(
                cluster_template_str=self.cluster_template
            )
        else:
            no_override = ImplicitResourceConfiguration.to_proto()

        if self.start_time or self.stop_time:
            interval_backfill = IntervalBackfillWindow.to_proto(
                backfill_start=self.start_time, backfill_end=self.stop_time
            )
        else:
            full_reset_backfill = FullResetBackfillWindow.to_proto()

        return ProtoBackfillSpec(
            featureset_name=self.featureset_name,
            interval_backfill=interval_backfill,
            full_reset_backfill=full_reset_backfill,
            comment=self.comment,
            backfill_type=backfill_type,
            no_override=no_override,
            explicit_configuration=explicit_configuration,
        )

    def trigger_batch_backfill(self) -> str:
        proto_backfill_spec: ProtoBackfillSpec = self._generate_backfill_spec_proto()

        return self._execution_management_client.trigger_batch_backfill(
            batch_backfill_spec=proto_backfill_spec
        ).execution_id

    @staticmethod
    def generate_expected_ticks_repr(
        start_time: datetime, stop_time: datetime, scheduling_policy: str
    ) -> List[str]:
        import croniter

        cron_ticks: List[datetime] = [
            t
            for t in croniter.croniter_range(
                start=start_time,
                stop=stop_time,
                expr_format=scheduling_policy,
                exclude_ends=False,
            )
        ]

        if not cron_ticks:
            cron_ticks = [start_time, stop_time.replace(microsecond=0)]
        else:
            if cron_ticks[0] > start_time:
                cron_ticks.insert(0, start_time)
            if cron_ticks[len(cron_ticks) - 1] < stop_time:
                cron_ticks.append(stop_time.replace(microsecond=0))

        def stitch(x: datetime, y: datetime) -> str:
            return f"{x.isoformat()} -> {y.isoformat()}"

        zipped_tick_strs: List[str] = [
            stitch(cron_ticks[i], cron_ticks[i + 1]) for i in range(len(cron_ticks) - 1)
        ]

        if len(zipped_tick_strs) > 10:
            zipped_tick_strs = zipped_tick_strs[:2] + ["<..>"] + zipped_tick_strs[-2:]

        return zipped_tick_strs



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PlatformSettings(google.protobuf.message.Message):
    """Container for all (JFrog) platform setting"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_SETTING_FIELD_NUMBER: builtins.int
    PROJECT_SETTING_FIELD_NUMBER: builtins.int
    @property
    def repository_setting(self) -> global___RepositorySetting:
        """Repo related setting"""
    @property
    def project_setting(self) -> global___ProjectSetting:
        """Project related setting"""
    def __init__(
        self,
        *,
        repository_setting: global___RepositorySetting | None = ...,
        project_setting: global___ProjectSetting | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["project_setting", b"project_setting", "repository_setting", b"repository_setting"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["project_setting", b"project_setting", "repository_setting", b"repository_setting"]) -> None: ...

global___PlatformSettings = PlatformSettings

class RepositorySetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_KEY_FIELD_NUMBER: builtins.int
    repository_key: builtins.str
    def __init__(
        self,
        *,
        repository_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["repository_key", b"repository_key"]) -> None: ...

global___RepositorySetting = RepositorySetting

class ProjectSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_KEY_FIELD_NUMBER: builtins.int
    project_key: builtins.str
    """JFrog project key"""
    def __init__(
        self,
        *,
        project_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["project_identifier", b"project_identifier", "project_key", b"project_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["project_identifier", b"project_identifier", "project_key", b"project_key"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["project_identifier", b"project_identifier"]) -> typing_extensions.Literal["project_key"] | None: ...

global___ProjectSetting = ProjectSetting
